from servicelayer import settings


def get_fakeredis(decode_responses=True):
    from fakeredis import FakeRedis
    if not hasattr(settings, '_redis_fake'):
        settings._redis_fake = FakeRedis(decode_responses=decode_responses)
    return settings._redis_fake


def get_redis(decode_responses=True):
    from redis import ConnectionPool, Redis
    if settings.REDIS_URL is None:
        return get_fakeredis(decode_responses=True)
    if not hasattr(settings, '_redis_pool'):
        settings._redis_pool = ConnectionPool.from_url(settings.REDIS_URL)
    return Redis(connection_pool=settings._redis_pool,
                 decode_responses=decode_responses)



from setuptools import setup, find_packages


setup(
    name='servicelayer',
    version='0.1.1',
    description="Basic remote service functions for alephdata components",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    keywords='storage files s3',
    author='Organized Crime and Corruption Reporting Project',
    author_email='data@occrp.org',
    url='http://github.com/alephdata/servicelayer',
    license='MIT',
    packages=find_packages(exclude=['ez_setup', 'examples', 'test']),
    namespace_packages=[],
    include_package_data=True,
    zip_safe=True,
    install_requires=[
        'banal',
        'grpcio',
        'protobuf >= 3.6.1',
    ],
    tests_require=[
        'coverage'
    ],
    test_suite='test',
    entry_points={
    }
)
